# Baltoslave
[![Documentation Status](https://readthedocs.org/projects/baltoslave/badge/?version=latest)](https://baltoslave.readthedocs.io/en/latest/?badge=latest)
[![Licence](https://img.shields.io/github/license/Shadow15510/Baltoslav?color=green)](https://github.com/Shadow15510/Baltoslav/blob/master/LICENSE)
[![Build Status](https://github.com/Shadow15510/Baltoslav/actions/workflows/python-publish.yml/badge.svg)](https://github.com/Shadow15510/Baltoslav/blob/master/.github/workflows/python-publish.yml)

## Description
This package provides:
- a small AI that plays to 'Guess the Language' on [Baltoslav](https://baltoslav.eu/adhadaj/index.php?mova=en);
- an offline version of this game.

A full documentation is available on [Read the Docs](https://baltoslave.readthedocs.io/en/latest/).

## Installation
This package is automatically deployed on [PyPI](https://pypi.org/project/Baltoslav/) so please consider using: `pip install baltoslav`.

## Licence
This code is provided under the GNU General Public Licence v3.0+ (GPLv3+).

Please refer to LICENCE file for further informations. 
